/* tslint:disable */
/* eslint-disable */
/**
*/
export enum BootRom {
  Dmg = 0,
  Sgb = 1,
  DmgBootix = 2,
  MgbBootix = 3,
  Cgb = 4,
  None = 5,
}
/**
* Enumeration that describes the multiple running
*/
export enum GameBoyMode {
  Dmg = 1,
  Cgb = 2,
  Sgb = 3,
}
/**
*/
export enum GameBoySpeed {
  Normal = 0,
  Double = 1,
}
/**
*/
export enum PadKey {
  Up = 0,
  Down = 1,
  Left = 2,
  Right = 3,
  Start = 4,
  Select = 5,
  A = 6,
  B = 7,
}
/**
*/
export enum PpuMode {
  HBlank = 0,
  VBlank = 1,
  OamRead = 2,
  VramRead = 3,
}
/**
*/
export enum RomType {
  RomOnly = 0,
  Mbc1 = 1,
  Mbc1Ram = 2,
  Mbc1RamBattery = 3,
  Mbc2 = 5,
  Mbc2Battery = 6,
  RomRam = 8,
  RomRamBattery = 9,
  Mmm01 = 11,
  Mmm01Ram = 12,
  Mmm01RamBattery = 13,
  Mbc3TimerBattery = 15,
  Mbc3TimerRamBattery = 16,
  Mbc3 = 17,
  Mbc3Ram = 18,
  Mbc3RamBattery = 19,
  Mbc5 = 25,
  Mbc5Ram = 26,
  Mbc5RamBattery = 27,
  Mbc5Rumble = 28,
  Mbc5RumbleRam = 29,
  Mbc5RumbleRamBattery = 30,
  Mbc6 = 32,
  Mbc7SensorRumbleRamBattery = 34,
  PocketCamera = 252,
  BandaiTama5 = 253,
  HuC3 = 254,
  HuC1RamBattery = 255,
  Unknown = 239,
}
/**
*/
export enum RomSize {
  Size32K = 0,
  Size64K = 1,
  Size128K = 2,
  Size256K = 3,
  Size512K = 4,
  Size1M = 5,
  Size2M = 6,
  Size4M = 7,
  Size8M = 8,
  SizeUnknown = 9,
}
/**
*/
export enum RamSize {
  NoRam = 0,
  Unused = 1,
  Size8K = 2,
  Size16K = 3,
  Size32K = 4,
  Size64K = 5,
  Size128K = 6,
  SizeUnknown = 7,
}
/**
*/
export enum CgbMode {
  NoCgb = 0,
  CgbCompatible = 128,
  CgbOnly = 192,
}
/**
* Structure that defines the ROM and ROM contents
* of a Game Boy cartridge. Should correctly address
* the specifics of all the major MBCs (Memory Bank
* Controllers).
*/
export class Cartridge {
  free(): void;
/**
* @returns {string}
*/
  title(): string;
/**
* @returns {number}
*/
  cgb_flag(): number;
/**
* @returns {number}
*/
  gb_mode(): number;
/**
* A cartridge is considered legacy if it does
* not have a CGB flag bit (bit 7 of 0x0143) set.
* These are the monochromatic only Cartridges built
* for the original DMG Game Boy.
* @returns {boolean}
*/
  is_legacy(): boolean;
/**
* @returns {number}
*/
  rom_type(): number;
/**
* @param {number} rom_type
*/
  set_rom_type(rom_type: number): void;
/**
* @returns {number}
*/
  rom_size(): number;
/**
* @returns {number}
*/
  ram_size(): number;
/**
* @returns {string}
*/
  rom_type_s(): string;
/**
* @returns {string}
*/
  rom_size_s(): string;
/**
* @returns {string}
*/
  ram_size_s(): string;
/**
* @returns {boolean}
*/
  has_battery(): boolean;
/**
* @returns {Uint8Array}
*/
  rom_data_eager(): Uint8Array;
/**
* @returns {Uint8Array}
*/
  ram_data_eager(): Uint8Array;
/**
* @param {Uint8Array} data
*/
  set_ram_data(data: Uint8Array): void;
/**
*/
  clear_ram_data(): void;
/**
* @param {number} column_length
* @returns {string}
*/
  description(column_length: number): string;
}
/**
* Top level structure that abstracts the usage of the
* Game Boy system under the Boytacean emulator.
* Should serve as the main entry-point API.
*/
export class GameBoy {
  free(): void;
/**
* @param {number | undefined} mode
*/
  constructor(mode?: number);
/**
*/
  reset(): void;
/**
*/
  reload(): void;
/**
* @returns {number}
*/
  clock(): number;
/**
* Risky function that will clock the CPU multiple times
* allowing an undefined number of cycles to be executed
* in the other Game Boy components.
* This can cause unwanted behaviour in components like
* the PPU where only one mode switch operation is expected
* per each clock call.
* @param {number} count
* @returns {number}
*/
  clock_m(count: number): number;
/**
* @param {number} key
*/
  key_press(key: number): void;
/**
* @param {number} key
*/
  key_lift(key: number): void;
/**
* @returns {number}
*/
  cpu_clock(): number;
/**
* @param {number} cycles
*/
  ppu_clock(cycles: number): void;
/**
* @param {number} cycles
*/
  apu_clock(cycles: number): void;
/**
* @param {number} cycles
*/
  dma_clock(cycles: number): void;
/**
* @param {number} cycles
*/
  timer_clock(cycles: number): void;
/**
* @param {number} cycles
*/
  serial_clock(cycles: number): void;
/**
* @returns {number}
*/
  ppu_ly(): number;
/**
* @returns {number}
*/
  ppu_mode(): number;
/**
* @returns {number}
*/
  ppu_frame(): number;
/**
*/
  boot(): void;
/**
* @param {boolean} boot
*/
  load(boot: boolean): void;
/**
* @param {boolean} boot
*/
  load_dmg(boot: boolean): void;
/**
* @param {boolean} boot
*/
  load_cgb(boot: boolean): void;
/**
* @param {Uint8Array} data
*/
  load_boot(data: Uint8Array): void;
/**
* @param {number} boot_rom
*/
  load_boot_static(boot_rom: number): void;
/**
*/
  load_boot_default(): void;
/**
*/
  load_boot_dmg(): void;
/**
*/
  load_boot_cgb(): void;
/**
* @returns {Uint8Array}
*/
  vram_eager(): Uint8Array;
/**
* @returns {Uint8Array}
*/
  hram_eager(): Uint8Array;
/**
* @returns {Uint8Array}
*/
  frame_buffer_eager(): Uint8Array;
/**
* @param {boolean} clear
* @returns {Uint8Array}
*/
  audio_buffer_eager(clear: boolean): Uint8Array;
/**
* @returns {number}
*/
  audio_output(): number;
/**
* @returns {Uint8Array}
*/
  audio_all_output(): Uint8Array;
/**
* @returns {number}
*/
  audio_ch1_output(): number;
/**
* @returns {number}
*/
  audio_ch2_output(): number;
/**
* @returns {number}
*/
  audio_ch3_output(): number;
/**
* @returns {number}
*/
  audio_ch4_output(): number;
/**
* @returns {boolean}
*/
  audio_ch1_enabled(): boolean;
/**
* @param {boolean} enabled
*/
  set_audio_ch1_enabled(enabled: boolean): void;
/**
* @returns {boolean}
*/
  audio_ch2_enabled(): boolean;
/**
* @param {boolean} enabled
*/
  set_audio_ch2_enabled(enabled: boolean): void;
/**
* @returns {boolean}
*/
  audio_ch3_enabled(): boolean;
/**
* @param {boolean} enabled
*/
  set_audio_ch3_enabled(enabled: boolean): void;
/**
* @returns {boolean}
*/
  audio_ch4_enabled(): boolean;
/**
* @param {boolean} enabled
*/
  set_audio_ch4_enabled(enabled: boolean): void;
/**
* @returns {number}
*/
  audio_sampling_rate(): number;
/**
* @returns {number}
*/
  audio_channels(): number;
/**
* @returns {Cartridge}
*/
  cartridge_eager(): Cartridge;
/**
* @returns {Uint8Array}
*/
  ram_data_eager(): Uint8Array;
/**
* @param {Uint8Array} ram_data
*/
  set_ram_data(ram_data: Uint8Array): void;
/**
* @returns {Registers}
*/
  registers(): Registers;
/**
* Obtains the tile structure for the tile at the
* given index, no conversion in the pixel buffer
* is done so that the color reference is the GB one.
* @param {number} index
* @returns {Tile}
*/
  get_tile(index: number): Tile;
/**
* Obtains the pixel buffer for the tile at the
* provided index, converting the color buffer
* using the currently loaded (background) palette.
* @param {number} index
* @returns {Uint8Array}
*/
  get_tile_buffer(index: number): Uint8Array;
/**
* Obtains the name of the compiler that has been
* used in the compilation of the base Boytacean
* library. Can be used for diagnostics.
* @returns {string}
*/
  compiler(): string;
/**
* @returns {string}
*/
  compiler_version(): string;
/**
* @returns {string}
*/
  compilation_date(): string;
/**
* @returns {string}
*/
  compilation_time(): string;
/**
* @returns {boolean}
*/
  is_dmg(): boolean;
/**
* @returns {boolean}
*/
  is_cgb(): boolean;
/**
* @returns {boolean}
*/
  is_sgb(): boolean;
/**
* @returns {number}
*/
  speed(): number;
/**
* @returns {number}
*/
  multiplier(): number;
/**
* @returns {number}
*/
  mode(): number;
/**
* @param {number} value
*/
  set_mode(value: number): void;
/**
* @returns {boolean}
*/
  ppu_enabled(): boolean;
/**
* @param {boolean} value
*/
  set_ppu_enabled(value: boolean): void;
/**
* @returns {boolean}
*/
  apu_enabled(): boolean;
/**
* @param {boolean} value
*/
  set_apu_enabled(value: boolean): void;
/**
* @returns {boolean}
*/
  dma_enabled(): boolean;
/**
* @param {boolean} value
*/
  set_dma_enabled(value: boolean): void;
/**
* @returns {boolean}
*/
  timer_enabled(): boolean;
/**
* @param {boolean} value
*/
  set_timer_enabled(value: boolean): void;
/**
* @returns {boolean}
*/
  serial_enabled(): boolean;
/**
* @param {boolean} value
*/
  set_serial_enabled(value: boolean): void;
/**
* @param {boolean} value
*/
  set_all_enabled(value: boolean): void;
/**
* @returns {number}
*/
  clock_freq(): number;
/**
* @param {number} value
*/
  set_clock_freq(value: number): void;
/**
* @returns {string}
*/
  clock_freq_s(): string;
/**
*/
  attach_null_serial(): void;
/**
*/
  attach_stdout_serial(): void;
/**
*/
  attach_printer_serial(): void;
/**
* @returns {number}
*/
  display_width(): number;
/**
* @returns {number}
*/
  display_height(): number;
/**
* @returns {number}
*/
  ram_size(): number;
/**
* @returns {number}
*/
  vram_size(): number;
/**
* @param {number} column_length
* @returns {string}
*/
  description(column_length: number): string;
/**
*/
  static set_panic_hook_ws(): void;
/**
* @param {Uint8Array} data
* @returns {Cartridge}
*/
  load_rom_ws(data: Uint8Array): Cartridge;
/**
*/
  load_callbacks_ws(): void;
/**
*/
  load_null_ws(): void;
/**
*/
  load_logger_ws(): void;
/**
*/
  load_printer_ws(): void;
/**
* Updates the emulation mode using the cartridge
* of the provided data to obtain the CGB flag value.
* @param {Uint8Array} data
*/
  infer_mode_ws(data: Uint8Array): void;
/**
* @param {any[]} value
*/
  set_palette_colors_ws(value: any[]): void;
/**
* @returns {string | undefined}
*/
  wasm_engine_ws(): string | undefined;
}
/**
*/
export class GameBoyConfig {
  free(): void;
/**
* @returns {boolean}
*/
  is_dmg(): boolean;
/**
* @returns {boolean}
*/
  is_cgb(): boolean;
/**
* @returns {boolean}
*/
  is_sgb(): boolean;
/**
* @returns {number}
*/
  mode(): number;
/**
* @param {number} value
*/
  set_mode(value: number): void;
/**
* @returns {boolean}
*/
  ppu_enabled(): boolean;
/**
* @param {boolean} value
*/
  set_ppu_enabled(value: boolean): void;
/**
* @returns {boolean}
*/
  apu_enabled(): boolean;
/**
* @param {boolean} value
*/
  set_apu_enabled(value: boolean): void;
/**
* @returns {boolean}
*/
  dma_enabled(): boolean;
/**
* @param {boolean} value
*/
  set_dma_enabled(value: boolean): void;
/**
* @returns {boolean}
*/
  timer_enabled(): boolean;
/**
* @param {boolean} value
*/
  set_timer_enabled(value: boolean): void;
/**
* @returns {boolean}
*/
  serial_enabled(): boolean;
/**
* @param {boolean} value
*/
  set_serial_enabled(value: boolean): void;
/**
* @returns {number}
*/
  clock_freq(): number;
/**
* @param {number} value
*/
  set_clock_freq(value: number): void;
}
/**
*/
export class ObjectData {
  free(): void;
}
/**
* Represents a palette with the metadata that is
* associated with it.
*/
export class PaletteInfo {
  free(): void;
}
/**
*/
export class Registers {
  free(): void;
/**
*/
  a: number;
/**
*/
  b: number;
/**
*/
  c: number;
/**
*/
  d: number;
/**
*/
  e: number;
/**
*/
  h: number;
/**
*/
  l: number;
/**
*/
  ly: number;
/**
*/
  lyc: number;
/**
*/
  pc: number;
/**
*/
  scx: number;
/**
*/
  scy: number;
/**
*/
  sp: number;
/**
*/
  wx: number;
/**
*/
  wy: number;
}
/**
* Represents a tile within the Game Boy context,
* should contain the pixel buffer of the tile.
* The tiles are always 8x8 pixels in size.
*/
export class Tile {
  free(): void;
/**
* @param {number} x
* @param {number} y
* @returns {number}
*/
  get(x: number, y: number): number;
/**
* @param {number} x
* @param {number} y
* @param {boolean} xflip
* @param {boolean} yflip
* @returns {number}
*/
  get_flipped(x: number, y: number, xflip: boolean, yflip: boolean): number;
/**
* @param {number} x
* @param {number} y
* @param {number} value
*/
  set(x: number, y: number, value: number): void;
/**
* @returns {Uint8Array}
*/
  buffer(): Uint8Array;
}
/**
*/
export class TileData {
  free(): void;
}

export type InitInput = RequestInfo | URL | Response | BufferSource | WebAssembly.Module;

export interface InitOutput {
  readonly memory: WebAssembly.Memory;
  readonly __wbg_gameboyconfig_free: (a: number) => void;
  readonly gameboyconfig_is_dmg: (a: number) => number;
  readonly gameboyconfig_is_cgb: (a: number) => number;
  readonly gameboyconfig_is_sgb: (a: number) => number;
  readonly gameboyconfig_mode: (a: number) => number;
  readonly gameboyconfig_set_mode: (a: number, b: number) => void;
  readonly gameboyconfig_ppu_enabled: (a: number) => number;
  readonly gameboyconfig_set_ppu_enabled: (a: number, b: number) => void;
  readonly gameboyconfig_apu_enabled: (a: number) => number;
  readonly gameboyconfig_set_apu_enabled: (a: number, b: number) => void;
  readonly gameboyconfig_dma_enabled: (a: number) => number;
  readonly gameboyconfig_set_dma_enabled: (a: number, b: number) => void;
  readonly gameboyconfig_timer_enabled: (a: number) => number;
  readonly gameboyconfig_set_timer_enabled: (a: number, b: number) => void;
  readonly gameboyconfig_serial_enabled: (a: number) => number;
  readonly gameboyconfig_set_serial_enabled: (a: number, b: number) => void;
  readonly gameboyconfig_set_clock_freq: (a: number, b: number) => void;
  readonly __wbg_registers_free: (a: number) => void;
  readonly __wbg_get_registers_pc: (a: number) => number;
  readonly __wbg_set_registers_pc: (a: number, b: number) => void;
  readonly __wbg_get_registers_sp: (a: number) => number;
  readonly __wbg_set_registers_sp: (a: number, b: number) => void;
  readonly __wbg_get_registers_a: (a: number) => number;
  readonly __wbg_set_registers_a: (a: number, b: number) => void;
  readonly __wbg_get_registers_b: (a: number) => number;
  readonly __wbg_set_registers_b: (a: number, b: number) => void;
  readonly __wbg_get_registers_c: (a: number) => number;
  readonly __wbg_set_registers_c: (a: number, b: number) => void;
  readonly __wbg_get_registers_d: (a: number) => number;
  readonly __wbg_set_registers_d: (a: number, b: number) => void;
  readonly __wbg_get_registers_e: (a: number) => number;
  readonly __wbg_set_registers_e: (a: number, b: number) => void;
  readonly __wbg_get_registers_h: (a: number) => number;
  readonly __wbg_set_registers_h: (a: number, b: number) => void;
  readonly __wbg_get_registers_l: (a: number) => number;
  readonly __wbg_set_registers_l: (a: number, b: number) => void;
  readonly __wbg_get_registers_scy: (a: number) => number;
  readonly __wbg_set_registers_scy: (a: number, b: number) => void;
  readonly __wbg_get_registers_scx: (a: number) => number;
  readonly __wbg_set_registers_scx: (a: number, b: number) => void;
  readonly __wbg_get_registers_wy: (a: number) => number;
  readonly __wbg_set_registers_wy: (a: number, b: number) => void;
  readonly __wbg_get_registers_wx: (a: number) => number;
  readonly __wbg_set_registers_wx: (a: number, b: number) => void;
  readonly __wbg_get_registers_ly: (a: number) => number;
  readonly __wbg_set_registers_ly: (a: number, b: number) => void;
  readonly __wbg_get_registers_lyc: (a: number) => number;
  readonly __wbg_set_registers_lyc: (a: number, b: number) => void;
  readonly __wbg_gameboy_free: (a: number) => void;
  readonly gameboy_new: (a: number) => number;
  readonly gameboy_reset: (a: number) => void;
  readonly gameboy_reload: (a: number) => void;
  readonly gameboy_clock: (a: number) => number;
  readonly gameboy_clock_m: (a: number, b: number) => number;
  readonly gameboy_key_press: (a: number, b: number) => void;
  readonly gameboy_key_lift: (a: number, b: number) => void;
  readonly gameboy_cpu_clock: (a: number) => number;
  readonly gameboy_ppu_clock: (a: number, b: number) => void;
  readonly gameboy_apu_clock: (a: number, b: number) => void;
  readonly gameboy_dma_clock: (a: number, b: number) => void;
  readonly gameboy_timer_clock: (a: number, b: number) => void;
  readonly gameboy_serial_clock: (a: number, b: number) => void;
  readonly gameboy_ppu_ly: (a: number) => number;
  readonly gameboy_ppu_mode: (a: number) => number;
  readonly gameboy_ppu_frame: (a: number) => number;
  readonly gameboy_boot: (a: number) => void;
  readonly gameboy_load: (a: number, b: number) => void;
  readonly gameboy_load_dmg: (a: number, b: number) => void;
  readonly gameboy_load_cgb: (a: number, b: number) => void;
  readonly gameboy_load_boot: (a: number, b: number, c: number) => void;
  readonly gameboy_load_boot_static: (a: number, b: number) => void;
  readonly gameboy_load_boot_default: (a: number) => void;
  readonly gameboy_load_boot_dmg: (a: number) => void;
  readonly gameboy_load_boot_cgb: (a: number) => void;
  readonly gameboy_hram_eager: (a: number, b: number) => void;
  readonly gameboy_frame_buffer_eager: (a: number, b: number) => void;
  readonly gameboy_audio_buffer_eager: (a: number, b: number, c: number) => void;
  readonly gameboy_audio_output: (a: number) => number;
  readonly gameboy_audio_all_output: (a: number, b: number) => void;
  readonly gameboy_audio_ch1_output: (a: number) => number;
  readonly gameboy_audio_ch2_output: (a: number) => number;
  readonly gameboy_audio_ch3_output: (a: number) => number;
  readonly gameboy_audio_ch4_output: (a: number) => number;
  readonly gameboy_audio_ch1_enabled: (a: number) => number;
  readonly gameboy_set_audio_ch1_enabled: (a: number, b: number) => void;
  readonly gameboy_set_audio_ch2_enabled: (a: number, b: number) => void;
  readonly gameboy_audio_ch3_enabled: (a: number) => number;
  readonly gameboy_set_audio_ch3_enabled: (a: number, b: number) => void;
  readonly gameboy_audio_ch4_enabled: (a: number) => number;
  readonly gameboy_set_audio_ch4_enabled: (a: number, b: number) => void;
  readonly gameboy_audio_sampling_rate: (a: number) => number;
  readonly gameboy_audio_channels: (a: number) => number;
  readonly gameboy_cartridge_eager: (a: number) => number;
  readonly gameboy_ram_data_eager: (a: number, b: number) => void;
  readonly gameboy_set_ram_data: (a: number, b: number, c: number) => void;
  readonly gameboy_registers: (a: number) => number;
  readonly gameboy_get_tile: (a: number, b: number) => number;
  readonly gameboy_get_tile_buffer: (a: number, b: number, c: number) => void;
  readonly gameboy_compiler: (a: number, b: number) => void;
  readonly gameboy_compiler_version: (a: number, b: number) => void;
  readonly gameboy_compilation_date: (a: number, b: number) => void;
  readonly gameboy_compilation_time: (a: number, b: number) => void;
  readonly gameboy_is_dmg: (a: number) => number;
  readonly gameboy_is_cgb: (a: number) => number;
  readonly gameboy_is_sgb: (a: number) => number;
  readonly gameboy_speed: (a: number) => number;
  readonly gameboy_multiplier: (a: number) => number;
  readonly gameboy_mode: (a: number) => number;
  readonly gameboy_set_mode: (a: number, b: number) => void;
  readonly gameboy_ppu_enabled: (a: number) => number;
  readonly gameboy_set_ppu_enabled: (a: number, b: number) => void;
  readonly gameboy_apu_enabled: (a: number) => number;
  readonly gameboy_set_apu_enabled: (a: number, b: number) => void;
  readonly gameboy_dma_enabled: (a: number) => number;
  readonly gameboy_set_dma_enabled: (a: number, b: number) => void;
  readonly gameboy_timer_enabled: (a: number) => number;
  readonly gameboy_set_timer_enabled: (a: number, b: number) => void;
  readonly gameboy_serial_enabled: (a: number) => number;
  readonly gameboy_set_serial_enabled: (a: number, b: number) => void;
  readonly gameboy_set_all_enabled: (a: number, b: number) => void;
  readonly gameboy_clock_freq: (a: number) => number;
  readonly gameboy_set_clock_freq: (a: number, b: number) => void;
  readonly gameboy_clock_freq_s: (a: number, b: number) => void;
  readonly gameboy_attach_null_serial: (a: number) => void;
  readonly gameboy_attach_stdout_serial: (a: number) => void;
  readonly gameboy_attach_printer_serial: (a: number) => void;
  readonly gameboy_display_width: (a: number) => number;
  readonly gameboy_display_height: (a: number) => number;
  readonly gameboy_ram_size: (a: number) => number;
  readonly gameboy_vram_size: (a: number) => number;
  readonly gameboy_description: (a: number, b: number, c: number) => void;
  readonly gameboy_load_rom_ws: (a: number, b: number, c: number) => number;
  readonly gameboy_load_callbacks_ws: (a: number) => void;
  readonly gameboy_load_logger_ws: (a: number) => void;
  readonly gameboy_load_printer_ws: (a: number) => void;
  readonly gameboy_infer_mode_ws: (a: number, b: number, c: number) => void;
  readonly gameboy_set_palette_colors_ws: (a: number, b: number, c: number) => void;
  readonly gameboy_wasm_engine_ws: (a: number, b: number) => void;
  readonly __wbg_paletteinfo_free: (a: number) => void;
  readonly __wbg_tile_free: (a: number) => void;
  readonly tile_get: (a: number, b: number, c: number) => number;
  readonly tile_get_flipped: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly tile_set: (a: number, b: number, c: number, d: number) => void;
  readonly tile_buffer: (a: number, b: number) => void;
  readonly __wbg_tiledata_free: (a: number) => void;
  readonly __wbg_cartridge_free: (a: number) => void;
  readonly cartridge_title: (a: number, b: number) => void;
  readonly cartridge_cgb_flag: (a: number) => number;
  readonly cartridge_gb_mode: (a: number) => number;
  readonly cartridge_is_legacy: (a: number) => number;
  readonly cartridge_rom_type: (a: number) => number;
  readonly cartridge_set_rom_type: (a: number, b: number) => void;
  readonly cartridge_rom_size: (a: number) => number;
  readonly cartridge_ram_size: (a: number) => number;
  readonly cartridge_rom_type_s: (a: number, b: number) => void;
  readonly cartridge_rom_size_s: (a: number, b: number) => void;
  readonly cartridge_ram_size_s: (a: number, b: number) => void;
  readonly cartridge_has_battery: (a: number) => number;
  readonly cartridge_rom_data_eager: (a: number, b: number) => void;
  readonly cartridge_ram_data_eager: (a: number, b: number) => void;
  readonly cartridge_set_ram_data: (a: number, b: number, c: number) => void;
  readonly cartridge_clear_ram_data: (a: number) => void;
  readonly cartridge_description: (a: number, b: number, c: number) => void;
  readonly __wbg_objectdata_free: (a: number) => void;
  readonly gameboy_load_null_ws: (a: number) => void;
  readonly gameboy_audio_ch2_enabled: (a: number) => number;
  readonly gameboyconfig_clock_freq: (a: number) => number;
  readonly gameboy_set_panic_hook_ws: () => void;
  readonly gameboy_vram_eager: (a: number, b: number) => void;
  readonly __wbindgen_malloc: (a: number, b: number) => number;
  readonly __wbindgen_realloc: (a: number, b: number, c: number, d: number) => number;
  readonly __wbindgen_add_to_stack_pointer: (a: number) => number;
  readonly __wbindgen_free: (a: number, b: number, c: number) => void;
}

export type SyncInitInput = BufferSource | WebAssembly.Module;
/**
* Instantiates the given `module`, which can either be bytes or
* a precompiled `WebAssembly.Module`.
*
* @param {SyncInitInput} module
*
* @returns {InitOutput}
*/
export function initSync(module: SyncInitInput): InitOutput;

/**
* If `module_or_path` is {RequestInfo} or {URL}, makes a request and
* for everything else, calls `WebAssembly.instantiate` directly.
*
* @param {InitInput | Promise<InitInput>} module_or_path
*
* @returns {Promise<InitOutput>}
*/
export default function __wbg_init (module_or_path?: InitInput | Promise<InitInput>): Promise<InitOutput>;
